summaryrefslogtreecommitdiffstats
path: root/parts/classview/classtooldlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/classview/classtooldlg.h')
-rw-r--r--parts/classview/classtooldlg.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/parts/classview/classtooldlg.h b/parts/classview/classtooldlg.h
index a33c7f2b..c8d88e71 100644
--- a/parts/classview/classtooldlg.h
+++ b/parts/classview/classtooldlg.h
@@ -45,7 +45,7 @@ public slots:
/** View nothing. */
void viewNone();
/** View the tqparents of the current class. */
void viewParents();
/** View the tqchildren of the current class. */
void viewChildren();
@@ -53,9 +53,9 @@ public slots:
void viewClients();
/** View all classes that this class has as attributes. */
void viewSuppliers();
/** View methods in this class and tqparents. */
void viewMethods();
/** View attributes in this class and tqparents. */
void viewAttributes();
private slots:
@@ -75,7 +75,7 @@ private:
ClassToolWidget *class_tree;
TQComboBox *class_combo;
- TQToolButton *tqparents_button;
+ TQToolButton *parents_button;
TQToolButton *tqchildren_button;
TQToolButton *clients_button;
TQToolButton *suppliers_button;
@@ -45,7 +45,7 @@ public slots:
/** View nothing. */
void viewNone();
- /** View the tqparents of the current class. */
+ /** View the parents of the current class. */
void viewParents();
/** View the tqchildren of the current class. */
@@ -53,9 +53,9 @@ public slots:
/** View all classes that this class has as attributes. */
void viewSuppliers();
- /** View methods in this class and tqparents. */
+ /** View methods in this class and parents. */
void viewMethods();
@@ -53,9 +53,9 @@ public slots:
void viewMethods();
- /** View attributes in this class and tqparents. */
+ /** View attributes in this class and parents. */
void viewAttributes();
private slots: